import * as cdk from "../../core";
import * as constructs from "constructs";
import * as cfn_parse from "../../core/lib/helpers-internal";
/**
 * Resource Type definition for AWS::SecurityLake::AwsLogSource.
 *
 * @cloudformationResource AWS::SecurityLake::AwsLogSource
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securitylake-awslogsource.html
 */
export declare class CfnAwsLogSource extends cdk.CfnResource implements cdk.IInspectable {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME: string;
    /**
     * Build a CfnAwsLogSource from CloudFormation properties
     *
     * A factory method that creates a new instance of this class from an object
     * containing the CloudFormation properties of this resource.
     * Used in the @aws-cdk/cloudformation-include module.
     *
     * @internal
     */
    static _fromCloudFormation(scope: constructs.Construct, id: string, resourceAttributes: any, options: cfn_parse.FromCloudFormationOptions): CfnAwsLogSource;
    /**
     * AWS account where you want to collect logs from.
     */
    accounts?: Array<string>;
    /**
     * The ARN for the data lake.
     */
    dataLakeArn: string;
    /**
     * The name for a AWS source.
     */
    sourceName: string;
    /**
     * The version for a AWS source.
     */
    sourceVersion: string;
    /**
     * @param scope Scope in which this resource is defined
     * @param id Construct identifier for this resource (unique in its scope)
     * @param props Resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnAwsLogSourceProps);
    protected get cfnProperties(): Record<string, any>;
    /**
     * Examines the CloudFormation resource and discloses attributes
     *
     * @param inspector tree inspector to collect and process attributes
     */
    inspect(inspector: cdk.TreeInspector): void;
    protected renderProperties(props: Record<string, any>): Record<string, any>;
}
/**
 * Properties for defining a `CfnAwsLogSource`
 *
 * @struct
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securitylake-awslogsource.html
 */
export interface CfnAwsLogSourceProps {
    /**
     * AWS account where you want to collect logs from.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securitylake-awslogsource.html#cfn-securitylake-awslogsource-accounts
     */
    readonly accounts?: Array<string>;
    /**
     * The ARN for the data lake.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securitylake-awslogsource.html#cfn-securitylake-awslogsource-datalakearn
     */
    readonly dataLakeArn: string;
    /**
     * The name for a AWS source.
     *
     * This must be a Regionally unique value.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securitylake-awslogsource.html#cfn-securitylake-awslogsource-sourcename
     */
    readonly sourceName: string;
    /**
     * The version for a AWS source.
     *
     * This must be a Regionally unique value.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securitylake-awslogsource.html#cfn-securitylake-awslogsource-sourceversion
     */
    readonly sourceVersion: string;
}
/**
 * Resource Type definition for AWS::SecurityLake::DataLake.
 *
 * @cloudformationResource AWS::SecurityLake::DataLake
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securitylake-datalake.html
 */
export declare class CfnDataLake extends cdk.CfnResource implements cdk.IInspectable, cdk.ITaggableV2 {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME: string;
    /**
     * Build a CfnDataLake from CloudFormation properties
     *
     * A factory method that creates a new instance of this class from an object
     * containing the CloudFormation properties of this resource.
     * Used in the @aws-cdk/cloudformation-include module.
     *
     * @internal
     */
    static _fromCloudFormation(scope: constructs.Construct, id: string, resourceAttributes: any, options: cfn_parse.FromCloudFormationOptions): CfnDataLake;
    /**
     * The Amazon Resource Name (ARN) created by you to provide to the subscriber.
     *
     * @cloudformationAttribute Arn
     */
    readonly attrArn: string;
    /**
     * The ARN for the Amazon Security Lake Amazon S3 bucket.
     *
     * @cloudformationAttribute S3BucketArn
     */
    readonly attrS3BucketArn: string;
    /**
     * Tag Manager which manages the tags for this resource
     */
    readonly cdkTagManager: cdk.TagManager;
    /**
     * Provides encryption details of Amazon Security Lake object.
     */
    encryptionConfiguration?: CfnDataLake.EncryptionConfigurationProperty | cdk.IResolvable;
    /**
     * Provides lifecycle details of Amazon Security Lake object.
     */
    lifecycleConfiguration?: cdk.IResolvable | CfnDataLake.LifecycleConfigurationProperty;
    /**
     * The Amazon Resource Name (ARN) used to index AWS Glue table partitions that are generated by the ingestion and normalization of AWS log sources and custom sources.
     */
    metaStoreManagerRoleArn?: string;
    /**
     * Provides replication details of Amazon Security Lake object.
     */
    replicationConfiguration?: cdk.IResolvable | CfnDataLake.ReplicationConfigurationProperty;
    tags?: Array<cdk.CfnTag>;
    /**
     * @param scope Scope in which this resource is defined
     * @param id Construct identifier for this resource (unique in its scope)
     * @param props Resource properties
     */
    constructor(scope: constructs.Construct, id: string, props?: CfnDataLakeProps);
    protected get cfnProperties(): Record<string, any>;
    /**
     * Examines the CloudFormation resource and discloses attributes
     *
     * @param inspector tree inspector to collect and process attributes
     */
    inspect(inspector: cdk.TreeInspector): void;
    protected renderProperties(props: Record<string, any>): Record<string, any>;
}
export declare namespace CfnDataLake {
    /**
     * Provides encryption details of Amazon Security Lake object.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-datalake-encryptionconfiguration.html
     */
    interface EncryptionConfigurationProperty {
        /**
         * The id of KMS encryption key used by Amazon Security Lake to encrypt the Security Lake object.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-datalake-encryptionconfiguration.html#cfn-securitylake-datalake-encryptionconfiguration-kmskeyid
         */
        readonly kmsKeyId?: string;
    }
    /**
     * Provides lifecycle details of Amazon Security Lake object.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-datalake-lifecycleconfiguration.html
     */
    interface LifecycleConfigurationProperty {
        /**
         * Provides data expiration details of Amazon Security Lake object.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-datalake-lifecycleconfiguration.html#cfn-securitylake-datalake-lifecycleconfiguration-expiration
         */
        readonly expiration?: CfnDataLake.ExpirationProperty | cdk.IResolvable;
        /**
         * Provides data storage transition details of Amazon Security Lake object.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-datalake-lifecycleconfiguration.html#cfn-securitylake-datalake-lifecycleconfiguration-transitions
         */
        readonly transitions?: Array<cdk.IResolvable | CfnDataLake.TransitionsProperty> | cdk.IResolvable;
    }
    /**
     * Provides data expiration details of Amazon Security Lake object.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-datalake-expiration.html
     */
    interface ExpirationProperty {
        /**
         * Number of days before data expires in the Amazon Security Lake object.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-datalake-expiration.html#cfn-securitylake-datalake-expiration-days
         */
        readonly days?: number;
    }
    /**
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-datalake-transitions.html
     */
    interface TransitionsProperty {
        /**
         * Number of days before data transitions to a different S3 Storage Class in the Amazon Security Lake object.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-datalake-transitions.html#cfn-securitylake-datalake-transitions-days
         */
        readonly days?: number;
        /**
         * The range of storage classes that you can choose from based on the data access, resiliency, and cost requirements of your workloads.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-datalake-transitions.html#cfn-securitylake-datalake-transitions-storageclass
         */
        readonly storageClass?: string;
    }
    /**
     * Provides replication details of Amazon Security Lake object.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-datalake-replicationconfiguration.html
     */
    interface ReplicationConfigurationProperty {
        /**
         * Replication enables automatic, asynchronous copying of objects across Amazon S3 buckets.
         *
         * Amazon S3 buckets that are configured for object replication can be owned by the same AWS account or by different accounts. You can replicate objects to a single destination bucket or to multiple destination buckets. The destination buckets can be in different AWS Regions or within the same Region as the source bucket.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-datalake-replicationconfiguration.html#cfn-securitylake-datalake-replicationconfiguration-regions
         */
        readonly regions?: Array<string>;
        /**
         * Replication settings for the Amazon S3 buckets.
         *
         * This parameter uses the AWS Identity and Access Management (IAM) role you created that is managed by Security Lake, to ensure the replication setting is correct.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-datalake-replicationconfiguration.html#cfn-securitylake-datalake-replicationconfiguration-rolearn
         */
        readonly roleArn?: string;
    }
}
/**
 * Properties for defining a `CfnDataLake`
 *
 * @struct
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securitylake-datalake.html
 */
export interface CfnDataLakeProps {
    /**
     * Provides encryption details of Amazon Security Lake object.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securitylake-datalake.html#cfn-securitylake-datalake-encryptionconfiguration
     */
    readonly encryptionConfiguration?: CfnDataLake.EncryptionConfigurationProperty | cdk.IResolvable;
    /**
     * Provides lifecycle details of Amazon Security Lake object.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securitylake-datalake.html#cfn-securitylake-datalake-lifecycleconfiguration
     */
    readonly lifecycleConfiguration?: cdk.IResolvable | CfnDataLake.LifecycleConfigurationProperty;
    /**
     * The Amazon Resource Name (ARN) used to index AWS Glue table partitions that are generated by the ingestion and normalization of AWS log sources and custom sources.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securitylake-datalake.html#cfn-securitylake-datalake-metastoremanagerrolearn
     */
    readonly metaStoreManagerRoleArn?: string;
    /**
     * Provides replication details of Amazon Security Lake object.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securitylake-datalake.html#cfn-securitylake-datalake-replicationconfiguration
     */
    readonly replicationConfiguration?: cdk.IResolvable | CfnDataLake.ReplicationConfigurationProperty;
    /**
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securitylake-datalake.html#cfn-securitylake-datalake-tags
     */
    readonly tags?: Array<cdk.CfnTag>;
}
/**
 * Resource Type definition for AWS::SecurityLake::Subscriber.
 *
 * @cloudformationResource AWS::SecurityLake::Subscriber
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securitylake-subscriber.html
 */
export declare class CfnSubscriber extends cdk.CfnResource implements cdk.IInspectable, cdk.ITaggableV2 {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME: string;
    /**
     * Build a CfnSubscriber from CloudFormation properties
     *
     * A factory method that creates a new instance of this class from an object
     * containing the CloudFormation properties of this resource.
     * Used in the @aws-cdk/cloudformation-include module.
     *
     * @internal
     */
    static _fromCloudFormation(scope: constructs.Construct, id: string, resourceAttributes: any, options: cfn_parse.FromCloudFormationOptions): CfnSubscriber;
    /**
     * @cloudformationAttribute ResourceShareArn
     */
    readonly attrResourceShareArn: string;
    /**
     * @cloudformationAttribute ResourceShareName
     */
    readonly attrResourceShareName: string;
    /**
     * @cloudformationAttribute S3BucketArn
     */
    readonly attrS3BucketArn: string;
    /**
     * @cloudformationAttribute SubscriberArn
     */
    readonly attrSubscriberArn: string;
    /**
     * @cloudformationAttribute SubscriberRoleArn
     */
    readonly attrSubscriberRoleArn: string;
    /**
     * The Amazon S3 or AWS Lake Formation access type.
     */
    accessTypes: Array<string>;
    /**
     * Tag Manager which manages the tags for this resource
     */
    readonly cdkTagManager: cdk.TagManager;
    /**
     * The ARN for the data lake.
     */
    dataLakeArn: string;
    /**
     * The supported AWS services from which logs and events are collected.
     */
    sources: Array<cdk.IResolvable | CfnSubscriber.SourceProperty> | cdk.IResolvable;
    /**
     * The description for your subscriber account in Security Lake.
     */
    subscriberDescription?: string;
    /**
     * The AWS identity used to access your data.
     */
    subscriberIdentity: cdk.IResolvable | CfnSubscriber.SubscriberIdentityProperty;
    /**
     * The name of your Security Lake subscriber account.
     */
    subscriberName: string;
    /**
     * An array of objects, one for each tag to associate with the subscriber.
     */
    tags?: Array<cdk.CfnTag>;
    /**
     * @param scope Scope in which this resource is defined
     * @param id Construct identifier for this resource (unique in its scope)
     * @param props Resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnSubscriberProps);
    protected get cfnProperties(): Record<string, any>;
    /**
     * Examines the CloudFormation resource and discloses attributes
     *
     * @param inspector tree inspector to collect and process attributes
     */
    inspect(inspector: cdk.TreeInspector): void;
    protected renderProperties(props: Record<string, any>): Record<string, any>;
}
export declare namespace CfnSubscriber {
    /**
     * The AWS identity used to access your data.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-subscriber-subscriberidentity.html
     */
    interface SubscriberIdentityProperty {
        /**
         * The external ID used to establish trust relationship with the AWS identity.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-subscriber-subscriberidentity.html#cfn-securitylake-subscriber-subscriberidentity-externalid
         */
        readonly externalId: string;
        /**
         * The AWS identity principal.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-subscriber-subscriberidentity.html#cfn-securitylake-subscriber-subscriberidentity-principal
         */
        readonly principal: string;
    }
    /**
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-subscriber-source.html
     */
    interface SourceProperty {
        /**
         * Amazon Security Lake supports log and event collection for natively supported AWS services.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-subscriber-source.html#cfn-securitylake-subscriber-source-awslogsource
         */
        readonly awsLogSource?: CfnSubscriber.AwsLogSourceProperty | cdk.IResolvable;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-subscriber-source.html#cfn-securitylake-subscriber-source-customlogsource
         */
        readonly customLogSource?: CfnSubscriber.CustomLogSourceProperty | cdk.IResolvable;
    }
    /**
     * Amazon Security Lake supports log and event collection for natively supported AWS services.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-subscriber-awslogsource.html
     */
    interface AwsLogSourceProperty {
        /**
         * The name for a AWS source.
         *
         * This must be a Regionally unique value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-subscriber-awslogsource.html#cfn-securitylake-subscriber-awslogsource-sourcename
         */
        readonly sourceName?: string;
        /**
         * The version for a AWS source.
         *
         * This must be a Regionally unique value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-subscriber-awslogsource.html#cfn-securitylake-subscriber-awslogsource-sourceversion
         */
        readonly sourceVersion?: string;
    }
    /**
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-subscriber-customlogsource.html
     */
    interface CustomLogSourceProperty {
        /**
         * The name for a third-party custom source.
         *
         * This must be a Regionally unique value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-subscriber-customlogsource.html#cfn-securitylake-subscriber-customlogsource-sourcename
         */
        readonly sourceName?: string;
        /**
         * The version for a third-party custom source.
         *
         * This must be a Regionally unique value.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-subscriber-customlogsource.html#cfn-securitylake-subscriber-customlogsource-sourceversion
         */
        readonly sourceVersion?: string;
    }
}
/**
 * Properties for defining a `CfnSubscriber`
 *
 * @struct
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securitylake-subscriber.html
 */
export interface CfnSubscriberProps {
    /**
     * The Amazon S3 or AWS Lake Formation access type.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securitylake-subscriber.html#cfn-securitylake-subscriber-accesstypes
     */
    readonly accessTypes: Array<string>;
    /**
     * The ARN for the data lake.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securitylake-subscriber.html#cfn-securitylake-subscriber-datalakearn
     */
    readonly dataLakeArn: string;
    /**
     * The supported AWS services from which logs and events are collected.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securitylake-subscriber.html#cfn-securitylake-subscriber-sources
     */
    readonly sources: Array<cdk.IResolvable | CfnSubscriber.SourceProperty> | cdk.IResolvable;
    /**
     * The description for your subscriber account in Security Lake.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securitylake-subscriber.html#cfn-securitylake-subscriber-subscriberdescription
     */
    readonly subscriberDescription?: string;
    /**
     * The AWS identity used to access your data.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securitylake-subscriber.html#cfn-securitylake-subscriber-subscriberidentity
     */
    readonly subscriberIdentity: cdk.IResolvable | CfnSubscriber.SubscriberIdentityProperty;
    /**
     * The name of your Security Lake subscriber account.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securitylake-subscriber.html#cfn-securitylake-subscriber-subscribername
     */
    readonly subscriberName: string;
    /**
     * An array of objects, one for each tag to associate with the subscriber.
     *
     * For each tag, you must specify both a tag key and a tag value. A tag value cannot be null, but it can be an empty string.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securitylake-subscriber.html#cfn-securitylake-subscriber-tags
     */
    readonly tags?: Array<cdk.CfnTag>;
}
